@@ -1,16 +1,16 @@
 //! Platform-independent high-level Emulator interaction module
-mod loaders;
+mod fastload;
+mod screenshot;
 mod snapshot;
 
 use crate::{
     error::RomLoadError,
     host::{
-        DataRecorder, Host, LoadableAsset, RomFormat, RomSet, SeekableAsset, Snapshot,
-        SnapshotRecorder, Tape,
+        DataRecorder, Host, LoadableAsset, RomFormat, RomSet, Screen, ScreenAsset, Snapshot,
+        SnapshotAsset, SnapshotRecorder, Stopwatch, Tape,
     },
     settings::RustzxSettings,
-    utils::EmulationSpeed,
-    z80::Z80,
+    utils::EmulationMode,
     zx::{
         controller::ZXController,
         events::EmulationEvents,
@@ -25,36 +25,31 @@ use crate::{
     },
     Result,
 };
+use core::time::Duration;
+use rustzx_z80::Z80;
 
 #[cfg(feature = "sound")]
 use crate::zx::sound::sample::SoundSample;
 #[cfg(feature = "autoload")]
 use crate::{host::BufferCursor, zx::machine::ZXMachine};
 
-use core::time::Duration;
-
 /// Represents main Emulator structure
 pub struct Emulator<H: Host> {
     settings: RustzxSettings,
     cpu: Z80,
     controller: ZXController<H>,
-    speed: EmulationSpeed,
+    mode: EmulationMode,
     fast_load: bool,
     #[cfg(feature = "sound")]
     sound_enabled: bool,
 }
 
-pub trait Stopwatch {
-    fn reset(&mut self);
-    fn measure(&self) -> Duration;
-}
-
 impl<H: Host> Emulator<H> {
     /// Constructs new emulator
     /// # Arguments
     /// `settings` - emulator settings
     pub fn new(settings: RustzxSettings, context: H::Context) -> Result<Self> {
-        let speed = settings.emulation_speed;
+        let mode = settings.emulation_mode;
         let fast_load = settings.tape_fastload_enabled;
         #[cfg(feature = "sound")]
         let sound_enabled = settings.sound_enabled;
@@ -66,7 +61,7 @@ impl<H: Host> Emulator<H> {
             settings,
             cpu,
             controller,
-            speed,
+            mode,
             fast_load,
             #[cfg(feature = "sound")]
             sound_enabled,
@@ -76,8 +71,8 @@ impl<H: Host> Emulator<H> {
     }
 
     /// changes emulation speed
-    pub fn set_speed(&mut self, new_speed: EmulationSpeed) {
-        self.speed = new_speed;
+    pub fn set_speed(&mut self, new_speed: EmulationMode) {
+        self.mode = new_speed;
     }
 
     /// changes fast loading flag
@@ -95,17 +90,14 @@ impl<H: Host> Emulator<H> {
     #[cfg(feature = "sound")]
     pub fn have_sound(&self) -> bool {
         // enable sound only if speed is normal
-        if let EmulationSpeed::Definite(1) = self.speed {
+        if let EmulationMode::FrameCount(1) = self.mode {
             self.sound_enabled
         } else {
             false
         }
     }
 
-    pub fn load_snapshot<A>(&mut self, snapshot: Snapshot<A>) -> Result<()>
-    where
-        A: LoadableAsset + SeekableAsset,
-    {
+    pub fn load_snapshot(&mut self, snapshot: Snapshot<impl SnapshotAsset>) -> Result<()> {
         match snapshot {
             Snapshot::Sna(asset) => snapshot::sna::load(self, asset),
         }
@@ -140,7 +132,7 @@ impl<H: Host> Emulator<H> {
         Ok(())
     }
 
-    fn load_rom_binary_16k_pages(&mut self, mut rom: H::RomSet) -> Result<()> {
+    fn load_rom_binary_16k_pages(&mut self, mut rom: impl RomSet) -> Result<()> {
         let page_count = self.settings.machine.specs().rom_pages;
 
         for page_index in 0..page_count {
@@ -152,12 +144,20 @@ impl<H: Host> Emulator<H> {
         Ok(())
     }
 
-    pub fn load_rom(&mut self, rom: H::RomSet) -> Result<()> {
+    pub fn load_rom(&mut self, rom: impl RomSet) -> Result<()> {
         match rom.format() {
             RomFormat::Binary16KPages => self.load_rom_binary_16k_pages(rom),
         }
     }
 
+    pub fn load_screen(&mut self, screen: Screen<impl ScreenAsset>) -> Result<()> {
+        match screen {
+            Screen::Scr(asset) => screenshot::scr::load(self, asset)?,
+        };
+
+        Ok(())
+    }
+
     pub fn play_tape(&mut self) {
         self.controller.tape.play();
     }
@@ -166,6 +166,12 @@ impl<H: Host> Emulator<H> {
         self.controller.tape.stop();
     }
 
+    /// Rewinds tape. May return error if underlying tape asset failed to
+    /// perform seek operaion to go back to the the beginning of the tape
+    pub fn rewind_tape(&mut self) -> Result<()> {
+        self.controller.tape.rewind()
+    }
+
     pub fn screen_buffer(&self) -> &H::FrameBuffer {
         self.controller.screen.frame_buffer()
     }
@@ -175,6 +181,14 @@ impl<H: Host> Emulator<H> {
         self.controller.border.frame_buffer()
     }
 
+    pub fn set_io_extender(&mut self, extender: H::IoExtender) {
+        self.controller.io_extender = Some(extender);
+    }
+
+    pub fn io_extender(&mut self) -> Option<&mut H::IoExtender> {
+        self.controller.io_extender.as_mut()
+    }
+
     pub fn border_color(&self) -> ZXColor {
         self.controller.border_color
     }
@@ -205,7 +219,7 @@ impl<H: Host> Emulator<H> {
         self.controller.send_mouse_wheel(dir);
     }
 
-    pub fn send_mouse_pos(&mut self, x: i8, y: i8) {
+    pub fn send_mouse_pos_diff(&mut self, x: i8, y: i8) {
         self.controller.send_mouse_pos_diff(x, y);
     }
 
@@ -219,22 +233,16 @@ impl<H: Host> Emulator<H> {
             && self.controller.tape.can_fast_load()
             && self.fast_load
         {
-            loaders::tap::fast_load_tap(self)?;
+            fastload::tap::fast_load_tap(self)?;
         }
         Ok(())
     }
 
-    /// Emulate frames, maximum in `max_time` time, returns emulation time in nanoseconds
-    /// in most cases time is max 1/50 of second, even when using
-    /// loader acceleration
-    pub fn emulate_frames<S>(&mut self, max_time: Duration, stopwatch: &mut S) -> Result<Duration>
-    where
-        S: Stopwatch,
-    {
-        let mut time = Duration::new(0, 0);
-        'frame: loop {
-            // start of current frame
-            stopwatch.reset();
+    /// Perform emulatio up to `emulation_limit` duration, returns actuall elapsed duration
+    pub fn emulate_frames(&mut self, emulation_limit: Duration) -> Result<Duration> {
+        let stopwatch = H::EmulationStopwatch::new();
+        // frame loop
+        loop {
             // reset controller internal frame counter
             self.controller.reset_frame_counter();
             'cpu: loop {
@@ -247,26 +255,24 @@ impl<H: Host> Emulator<H> {
                     self.process_events(self.controller.events())?;
                     self.controller.clear_events();
                 }
-                // If speed is defined
-                if let EmulationSpeed::Definite(multiplier) = self.speed {
-                    if self.controller.frames_count() >= multiplier {
-                        // no more frames
-                        return Ok(stopwatch.measure());
-                    };
-                // if speed is maximal.
-                } else {
-                    // if any frame passed then break cpu loop, but try to start new frame
-                    if self.controller.frames_count() != 0 {
-                        break 'cpu;
+
+                match self.mode {
+                    EmulationMode::FrameCount(frames) => {
+                        if self.controller.frames_count() >= frames {
+                            return Ok(stopwatch.measure());
+                        };
+                    }
+                    EmulationMode::Max => {
+                        if self.controller.frames_count() != 0 {
+                            break 'cpu;
+                        }
                     }
                 }
             }
-            time += stopwatch.measure();
             // if time is bigger than `max_time` then stop emulation cycle
-            if time > max_time {
-                break 'frame;
+            if stopwatch.measure() > emulation_limit {
+                return Ok(stopwatch.measure());
             }
         }
-        Ok(time)
     }
 }
