@@ -1,18 +1,19 @@
 #![no_std]
-#![allow(dead_code)]
 
 pub(crate) mod emulator;
 pub(crate) mod settings;
 pub(crate) mod utils;
-pub(crate) mod z80;
 
 pub mod error;
 pub mod host;
 pub mod zx;
 
-pub use emulator::{Emulator, Stopwatch};
+pub use emulator::Emulator;
 pub use settings::RustzxSettings;
-pub use utils::EmulationSpeed;
+pub use utils::EmulationMode;
+
+#[cfg(feature = "strum")]
+pub use strum::IntoEnumIterator as IterableEnum;
 
 extern crate alloc;
 
