@@ -1,10 +1,9 @@
 //! Contains ZX Spectrum System contrller (like ula or so) of emulator
 use crate::{
     error::Error,
-    host::{Host, HostContext},
+    host::{Host, HostContext, IoExtender},
     settings::RustzxSettings,
-    utils::{screen::bitmap_line_addr, split_word, Clocks},
-    z80::Z80Bus,
+    utils::screen::bitmap_line_addr,
     zx::{
         constants::{ADDR_LD_BREAK, CANVAS_HEIGHT, CLOCKS_PER_COL},
         events::EmulationEvents,
@@ -20,6 +19,7 @@ use crate::{
         video::{colors::ZXColor, screen::ZXScreen},
     },
 };
+use rustzx_z80::Z80Bus;
 
 #[cfg(feature = "embedded-roms")]
 use crate::zx::roms;
@@ -39,6 +39,7 @@ pub(crate) struct ZXController<H: Host> {
     pub border: ZXBorder<H::FrameBuffer>,
     pub kempston: Option<KempstonJoy>,
     pub mouse: Option<KempstonMouse>,
+    pub io_extender: Option<H::IoExtender>,
     #[cfg(feature = "sound")]
     pub mixer: ZXMixer,
     pub keyboard: [u8; 8],
@@ -48,14 +49,10 @@ pub(crate) struct ZXController<H: Host> {
     // current border color
     pub border_color: ZXColor,
     // clocls count from frame start
-    frame_clocks: Clocks,
+    frame_clocks: usize,
     // frames count, which passed during emulation invokation
     passed_frames: usize,
     events: EmulationEvents,
-    // audio in
-    mic: bool,
-    // audio out
-    ear: bool,
     paging_enabled: bool,
     screen_bank: u8,
     current_port_7ffd: u8,
@@ -67,6 +64,7 @@ pub(crate) struct ZXController<H: Host> {
 
 impl<H: Host> ZXController<H> {
     /// Returns new ZXController from settings
+    #[allow(clippy::let_and_return)]
     pub fn new(settings: &RustzxSettings, host_context: H::Context) -> Self {
         let (memory, paging, screen_bank);
         match settings.machine {
@@ -109,6 +107,7 @@ impl<H: Host> ZXController<H> {
             border,
             kempston,
             mouse,
+            io_extender: None,
             #[cfg(feature = "sound")]
             mixer,
             keyboard: [0xFF; 8],
@@ -116,12 +115,10 @@ impl<H: Host> ZXController<H> {
             keyboard_sinclair: [0xFF; 8],
             caps_shift_modifier_mask: 0,
             border_color: ZXColor::Black,
-            frame_clocks: Clocks(0),
+            frame_clocks: 0,
             passed_frames: 0,
             tape: Default::default(),
             events: Default::default(),
-            mic: false,
-            ear: false,
             paging_enabled: paging,
             screen_bank,
             current_port_7ffd: 0,
@@ -153,8 +150,9 @@ impl<H: Host> ZXController<H> {
     }
 
     /// returns current frame emulation pos in percents
+    #[cfg(feature = "sound")]
     fn frame_pos(&self) -> f64 {
-        let val = self.frame_clocks.count() as f64 / self.machine.specs().clocks_frame as f64;
+        let val = self.frame_clocks as f64 / self.machine.specs().clocks_frame as f64;
         if val > 1.0 {
             1.0
         } else {
@@ -241,10 +239,10 @@ impl<H: Host> ZXController<H> {
     fn floating_bus_value(&self) -> u8 {
         let specs = self.machine.specs();
         let clocks = self.frame_clocks;
-        if clocks.count() < specs.clocks_first_pixel + 2 {
+        if clocks < specs.clocks_first_pixel + 2 {
             return 0xFF;
         }
-        let clocks = clocks.count() - (specs.clocks_first_pixel + 2);
+        let clocks = clocks - (specs.clocks_first_pixel + 2);
         let row = clocks / specs.clocks_line;
         let clocks = clocks % specs.clocks_line;
         let col = (clocks / 8) * 2 + (clocks % 8) / 2;
@@ -269,7 +267,7 @@ impl<H: Host> ZXController<H> {
     }
 
     /// make contention + wait some clocks
-    fn do_contention_and_wait(&mut self, wait_time: Clocks) {
+    fn do_contention_and_wait(&mut self, wait_time: usize) {
         let contention = self.machine.contention_clocks(self.frame_clocks);
         self.wait_internal(contention + wait_time);
     }
@@ -288,19 +286,19 @@ impl<H: Host> ZXController<H> {
         if self.addr_is_contended(port) {
             self.do_contention();
         };
-        self.wait_internal(Clocks(1));
+        self.wait_internal(1);
     }
 
     /// Returns late IO contention clocks
     fn io_contention_last(&mut self, port: u16) {
         if self.machine.port_is_contended(port) {
-            self.do_contention_and_wait(Clocks(2));
+            self.do_contention_and_wait(2);
         } else if self.addr_is_contended(port) {
-            self.do_contention_and_wait(Clocks(1));
-            self.do_contention_and_wait(Clocks(1));
+            self.do_contention_and_wait(1);
+            self.do_contention_and_wait(1);
             self.do_contention();
         } else {
-            self.wait_internal(Clocks(2));
+            self.wait_internal(2);
         }
     }
 
@@ -333,11 +331,6 @@ impl<H: Host> ZXController<H> {
         self.passed_frames = 0;
     }
 
-    /// Returns current clocks from frame start
-    pub fn clocks(&self) -> Clocks {
-        self.frame_clocks
-    }
-
     pub fn write_7ffd(&mut self, val: u8) {
         if !self.paging_enabled {
             return;
@@ -390,7 +383,8 @@ impl<H: Host> ZXController<H> {
 
     pub(crate) fn set_border_color(
         &mut self,
-        #[allow(unused_variables)] clocks: Clocks,
+        #[cfg(feature = "precise-border")] clocks: usize,
+        #[cfg(not(feature = "precise-border"))] _clocks: usize,
         color: ZXColor,
     ) {
         self.border_color = color;
@@ -457,28 +451,25 @@ impl<H: Host> Z80Bus for ZXController<H> {
     }
 
     /// Cahnges internal state on clocks count change (emualtion processing)
-    fn wait_internal(&mut self, clk: Clocks) {
+    fn wait_internal(&mut self, clk: usize) {
         self.frame_clocks += clk;
         if let Err(e) = self.tape.process_clocks(clk) {
             self.last_emulation_error = Some(e);
         }
-        let mic = self.tape.current_bit();
-        self.mic = mic;
         #[cfg(feature = "sound")]
         {
             let pos = self.frame_pos();
-            self.mixer.beeper.change_bit(self.mic | self.ear);
             self.mixer.process(pos);
         }
         self.screen.process_clocks(self.frame_clocks);
-        if self.frame_clocks.count() >= self.machine.specs().clocks_frame {
+        if self.frame_clocks >= self.machine.specs().clocks_frame {
             self.new_frame();
             self.passed_frames += 1;
         }
     }
 
     // wait with memory request pin active
-    fn wait_mreq(&mut self, addr: u16, clk: Clocks) {
+    fn wait_mreq(&mut self, addr: u16, clk: usize) {
         match self.machine {
             ZXMachine::Sinclair48K | ZXMachine::Sinclair128K => {
                 // contention in low 16k RAM
@@ -491,7 +482,7 @@ impl<H: Host> Z80Bus for ZXController<H> {
     }
 
     /// wait without memory request pin active
-    fn wait_no_mreq(&mut self, addr: u16, clk: Clocks) {
+    fn wait_no_mreq(&mut self, addr: u16, clk: usize) {
         // only for 48 K!
         self.wait_mreq(addr, clk);
     }
@@ -501,9 +492,17 @@ impl<H: Host> Z80Bus for ZXController<H> {
         // all contentions check
         self.io_contention_first(port);
         self.io_contention_last(port);
+
+        let io_extender_value = self
+            .io_extender
+            .as_mut()
+            .and_then(|e| e.extends_port(port).then(|| e.read(port)));
+
         // find out what we need to do
-        let (h, _) = split_word(port);
-        let output = if port & 0x0001 == 0 {
+        let [_, h] = port.to_le_bytes();
+        let output = if let Some(value) = io_extender_value {
+            value
+        } else if port & 0x0001 == 0 {
             // ULA port
             let mut tmp: u8 = 0xFF;
             for n in 0..8 {
@@ -514,11 +513,14 @@ impl<H: Host> Z80Bus for ZXController<H> {
                     tmp &= keyboard_byte;
                 }
             }
-            // invert bit 6 if mic_hw active;
-            if self.mic {
+
+            // Emulate zx spectrum "issue 2" model.
+            // For future "issue 3" implementation condition will be `!self.ear`, but
+            // different zx spectrum "issues" emulation is not planned yet
+            if !self.tape.current_bit() {
                 tmp ^= 0x40;
             }
-            // 5 and 7 unused
+            // 5 and 7 bits are unused
             tmp
         } else if self.mouse.is_some() && (port & 0x0121 == 0x0001) {
             self.mouse.as_ref().unwrap().buttons_port
@@ -534,7 +536,7 @@ impl<H: Host> Z80Bus for ZXController<H> {
             self.floating_bus_value()
         };
         // add one clock after operation
-        self.wait_internal(Clocks(1));
+        self.wait_internal(1);
         output
     }
 
@@ -542,24 +544,33 @@ impl<H: Host> Z80Bus for ZXController<H> {
     fn write_io(&mut self, port: u16, data: u8) {
         // first contention
         self.io_contention_first(port);
+
         // find active port
-        if port & 0xC002 == 0xC000 {
+        if self
+            .io_extender
+            .as_ref()
+            .map_or(false, |e| e.extends_port(port))
+        {
+            self.io_extender.as_mut().unwrap().write(port, data);
+        } else if port & 0xC002 == 0xC000 {
             self.select_ay_reg(data);
         } else if port & 0xC002 == 0x8000 {
             self.write_ay_port(data);
         } else if port & 0x0001 == 0 {
             self.set_border_color(self.frame_clocks, ZXColor::from_bits(data & 0x07));
-            self.mic = data & 0x08 != 0;
-            self.ear = data & 0x10 != 0;
             #[cfg(feature = "sound")]
-            self.mixer.beeper.change_bit(self.mic | self.ear);
+            {
+                let mic = data & 0x08 != 0;
+                let ear = data & 0x10 != 0;
+                self.mixer.beeper.change_state(ear, mic);
+            }
         } else if (port & 0x8002 == 0) && (self.machine == ZXMachine::Sinclair128K) {
             self.write_7ffd(data);
         }
         // last contention after byte write
         self.io_contention_last(port);
         // add one clock after operation
-        self.wait_internal(Clocks(1));
+        self.wait_internal(1);
     }
 
     /// value, requested during `INT0` interrupt
@@ -569,7 +580,7 @@ impl<H: Host> Z80Bus for ZXController<H> {
 
     /// checks system maskable interrupt pin state
     fn int_active(&self) -> bool {
-        self.frame_clocks.count() % self.machine.specs().clocks_frame
+        self.frame_clocks % self.machine.specs().clocks_frame
             < self.machine.specs().interrupt_length
     }
 
