@@ -1,10 +1,18 @@
 /// Kempston key type. Port bit encoded in enum values
+#[cfg_attr(feature = "strum", derive(strum::EnumIter))]
+#[derive(Clone, Copy)]
 pub enum KempstonKey {
     Right = 0x01,
     Left = 0x02,
     Down = 0x04,
     Up = 0x08,
     Fire = 0x10,
+    /// Undocumented extra button 1
+    Ext1 = 0x20,
+    /// Undocumented extra button 2
+    Ext2 = 0x40,
+    /// Undocumented extra button 3
+    Ext3 = 0x80,
 }
 
 /// Kempston Joystick
