@@ -1,5 +1,7 @@
 use crate::zx::keys::ZXKey;
 
+#[cfg_attr(feature = "strum", derive(strum::EnumIter))]
+#[derive(Debug, Clone, Copy)]
 pub enum SinclairKey {
     Left,
     Right,
@@ -8,6 +10,8 @@ pub enum SinclairKey {
     Fire,
 }
 
+#[cfg_attr(feature = "strum", derive(strum::EnumIter))]
+#[derive(Debug, Clone, Copy)]
 pub enum SinclairJoyNum {
     Fist,
     Second,
