@@ -2,7 +2,8 @@
 
 /// Struct, which contains mast and port of key
 #[rustfmt::skip]
-#[derive(Clone, Copy)]
+#[cfg_attr(feature = "strum", derive(strum::EnumIter))]
+#[derive(Debug, Clone, Copy)]
 pub enum ZXKey {
     // Port 0xFEFE
     Shift, Z, X, C, V,
@@ -22,7 +23,8 @@ pub enum ZXKey {
     Space, SymShift, M, N, B,
 }
 
-#[derive(Clone, Copy)]
+#[cfg_attr(feature = "strum", derive(strum::EnumIter))]
+#[derive(Debug, Clone, Copy)]
 pub enum CompoundKey {
     ArrowLeft,
     ArrowRight,
