@@ -1,4 +1,4 @@
-use crate::{utils::Clocks, zx::tape::TapeImpl, Result};
+use crate::{zx::tape::TapeImpl, Result};
 
 pub struct Empty;
 
@@ -19,7 +19,7 @@ impl TapeImpl for Empty {
         false
     }
 
-    fn process_clocks(&mut self, _clocks: Clocks) -> Result<()> {
+    fn process_clocks(&mut self, _clocks: usize) -> Result<()> {
         Ok(())
     }
 
