@@ -1,11 +1,11 @@
 mod empty;
 mod tap;
 
-pub use self::{empty::Empty, tap::Tap};
+pub use empty::Empty;
+pub use tap::Tap;
 
 use crate::{
     host::{LoadableAsset, SeekableAsset},
-    utils::Clocks,
     Result,
 };
 
@@ -33,7 +33,7 @@ pub trait TapeImpl {
     /// Returns current tape (`ear`) bit
     fn current_bit(&self) -> bool;
     /// Perform tape processing emulation within `clocks` time limit
-    fn process_clocks(&mut self, clocks: Clocks) -> Result<()>;
+    fn process_clocks(&mut self, clocks: usize) -> Result<()>;
     fn stop(&mut self);
     fn play(&mut self);
     /// Rewinds tape content to the beginning
